@@ -32,6 +32,16 @@ module.exports = function(hg) {
 		if (item.domain == 'members' && !item.public) {
 			return false;
 		}
+		if (item.domain == 'discussions' && item.group_ids && item.group_ids[0]) {
+			var gid = item.group_ids[0];
+			if (!hg.groupPerms[gid] || !hg.groupPerms[gid].params.forum) {
+				return false;
+			}
+			var perms = hg.groupPerms[gid].params.forum;
+			if (perms == 'nobody' || (perms == 'registered' && !args.uid) || (perms == 'members' && !args.groupMap[gid])) {
+				return false;
+			}
+		}
 
 		if (item.access !== undefined && item.access > 0 && !args.uid) {
 			return false;
@@ -58,7 +68,7 @@ module.exports = function(hg) {
 
 	var freqMap = function(str) {
 		var rv = {}, total = 0;
-		if (!str) { 
+		if (!str) {
 			str = '';
 		}
 		str
@@ -392,6 +402,9 @@ module.exports = function(hg) {
 		['tags', 'users', 'inGroup'].forEach(function(k) {
 			args[k] = args[k] ? args[k].split(',') : [];
 		});
+		if (args.urlImplicitGroup) {
+			args.domain = 'resources';
+		}
 		hg.log(args);
 		var rv = {
 			'js': null,
@@ -609,11 +622,16 @@ module.exports = function(hg) {
 				seeded = true;
 				rv.results = hg.select('aliases', 'group:' + args.inGroup[0]).out('alias');
 			}
+			else if (args.domain.length) {
+				seeded = true;
+				rv.results = hg.select('domains', args.domain).out('domain');
+			}
+
 			['tags', 'users'].forEach(function(al) {
 				if (args[al].length) {
 					args[al].forEach(function(id) {
 						var items = hg.select('aliases', al.replace(/s$/, '')  + ':' + id).out('alias');
-	
+
 						if (seeded) {
 							rv.results = rv.results.intersect(items);
 						}
@@ -627,7 +645,7 @@ module.exports = function(hg) {
 			});
 			if (args.timeframe.length) {
 				switch (args.timeframe) {
-					case 'day': case 'week': case 'month': case 'year':	
+					case 'day': case 'week': case 'month': case 'year':
 						// if we put in potentially-valid results by selecting the last two years, isValid will pick out the ones for the actually-relevant timeframe
 						var items = hg.select('years', now.getFullYear()).out('timeframe')
 							.union(hg.select('years', now.getFullYear() - 1).out('timeframe'));
